library(rugarch)

sp500 <- read.table("sp500.dat")
gs <- read.table("goldmanSacks.dat")
ford <- read.table("ford.dat")

# Add name "Data" in Line 1 in sp500.dat, then
D <- read.table("sp500.dates")
t <- D[,1]
D <- strptime(t, "%Y-%m-%d") #convert to  POSIXlt (a date class)
D <- D[2:659]

spD=100*diff(log(sp500[,6]))
gsD=100*diff(log(gs[,6]))
fdD=100*diff(log(ford[,6]))

ps.options(horizontal=F, width=4.8, height=5, pointsize=9)
postscript("Fig310.eps", onefile=F, print=F)
par(mar=c(3,3,3,1),mfrow=c(3,2), mgp=c(1.8,0.6,0))

 m2 = ugarchspec(variance.model=list(model="sGARCH", garchOrder=c(1,1)),  mean.model=list(armaOrder=c(0,0), include.mean=F))
 sp=ugarchfit(m2, spD)
 gs=ugarchfit(m2, gsD)
 fd=ugarchfit(m2, fdD)

m1 = ugarchspec(variance.model=list(model="eGARCH", garchOrder=c(1,1)),  mean.model=list(armaOrder=c(0,0), include.mean=F))
sp500EG=ugarchfit(m1, spD)
gsEG=ugarchfit(m1, gsD)
fdEG=ugarchfit(m1, fdD)

# library(TSA)
# sp=garch(100*diff(log(sp500[,6])), order=c(1,1))
# gs=garch(100*diff(log(gs[,6])), order=c(1,1))
# fd=garch(100*diff(log(ford[,6])), order=c(1,1))

qqnorm(spD/sigma(sp), xlab='Normal quantiles', ylab='Residual quantiles', 
    main="S&P500, GARCH(1,1)", col="blue")
qqline(spD/sigma(sp), col="red")
qqnorm(spD/sigma(sp500EG), xlab='Normal quantiles', ylab='Residual quantiles', 
    main="S&P500, EGARCH(1,1)", col="blue")
qqline(spD/sigma(sp500EG), col="red")
qqnorm(gsD/sigma(gs), xlab='Normal quantiles', ylab='Residual quantiles', 
    main="Goldman Sacks, GARCH(1,1)", col="blue")
qqline(gsD/sigma(gs), col="red")
qqnorm(gsD/sigma(gsEG), xlab='Normal quantiles', ylab='Residual quantiles', 
    main="Goldman Sacks, EGARCH(1,1)", col="blue")
qqline(gsD/sigma(gsEG), col="red")
qqnorm(fdD/sigma(fd), xlab='Normal quantiles', ylab='Residual quantiles', 
    main="Ford, GARCH(1,1)", col="blue")
qqline(fdD/sigma(fd), col="red")
qqnorm(fdD/sigma(fdEG), xlab='Normal quantiles', ylab='Residual quantiles', 
    main="Ford, EGARCH(1,1)", col="blue")
qqline(fdD/sigma(fdEG), col="red")



dev.off()

